@@ -4,6 +4,7 @@ import os
 import datetime
 import pickle
 
+devmode = False
 
 class __TQL:
     __qdbpath = 'S:/all member/퀀트운용팀/93 QuickDB/'
@@ -26,13 +27,14 @@ class __TQL:
     @classmethod
     def save_pkl(cls, data, dest):
         try:
-            with open(dest, 'data') as f:
+            with open(dest, 'wb') as f:
                 pickle.dump(data, f)
         except:
             return None
 
     @classmethod
     def add_user(cls, username):
+        print(cls.__qdbpath+"authentification.tql")
         users = cls.load_pkl(cls.__qdbpath+"authentification.tql")
         users.add(username)
         cls.save_pkl(users, cls.__qdbpath+"authentification.tql")
@@ -102,6 +104,8 @@ class ts(__TQL):
         y2 = int(end[:4])
         res = []
         for year in range(y1, y2+1):
+            if devmode:
+                print(year)
             _ = super().load_pkl(super().qdb(f"ts/{year}_0.data"))
             if _ is not None:
                 res.append(_)
@@ -130,6 +134,7 @@ class ts(__TQL):
                     res.append(_)
             df = pd.concat(res).sort_index().loc[start:end]
         except Exception as e:
+            print(e)
             raise e
         return df
     
@@ -171,6 +176,11 @@ class ts(__TQL):
         no = 12
         return cls.__getTS(no, start, end)
     
+    @classmethod 
+    def trdstp(cls, start, end=None):
+        no = 88
+        return cls.__getTS(no, start, end)
+    
     @classmethod
     def pr_open(cls, start, end=None):
         no = 13
